//
//  ReleaseCommand.swift
//  Escape
//
//  Created by Salma Ali on 9/9/18.
//

import Foundation
import SwiftCLI
import SwiftShell

class XamarinReleaseCommand: Command {
    let name = "release"
    let shortDescription = "Fetches the latest Native SDKS, build, binds and packs then commits these changes to the repo and creates a pull request"
    let newVersion = Key<String>("-v", "--version", description: "Enters the new version for the nuget package.")
    
    func execute() {
        do {
            let xamarinProjectDirectory = main.currentdirectory
            
            // Fetching iOS and android native repos
            Git.fetch(platform: Constants.platforms.iOS, repositoryName: .iOS)
            Git.fetch(platform: Constants.platforms.android, repositoryName: .android)
            
            // Building native android project
            Helpers.buildNativeLibrary(platform: Constants.platforms.android)
            
            main.currentdirectory = xamarinProjectDirectory
            
            try Git.checkout(branchName: newVersion.value!)
            
            // Binds aar libraries to corresponding android packages
            XamarinHelpers.bindNativeLibrary(platform: Constants.platforms.android)
            
            // Binds native framework to iOS Package
            XamarinHelpers.bindNativeLibrary(platform: Constants.platforms.iOS)
            
            let changelog = Helpers.getChangelog()
            var markdownChangelog = ""
            for change in changelog {
                markdownChangelog += change + "\n"
            }
            XamarinHelpers.editNuspecFile(module: "\(XamarinConstants.AndroidMainModule)/\(XamarinConstants.AndroidMainModule)/\(XamarinConstants.AndroidMainModule)", newVersion: newVersion.value!, releaseNotes: markdownChangelog)
            XamarinHelpers.editNuspecFile(module: "\(XamarinConstants.iOSModule)/\(XamarinConstants.iOSModule)/\(XamarinConstants.iOSModule)", newVersion: newVersion.value!, releaseNotes: markdownChangelog)
            
            try Git.addAll()
            try Git.commit(message: "Bumping to version \(newVersion.value!)")
            try Git.push(origin: newVersion.value!)
            
            try GitHub.createPullRequest(repoAt: .xamarin, withTitle: "Bumping to \(newVersion.value!)", withBody: "Initial pull request with the new native libraries", atHead: "\(newVersion.value!)")
        } catch {
            print(error)
            exit(1)
        }
    }
}

